BOOST_LANG language standards macros

### `BOOST_LANG` language standards macros

##### `BOOST_LANG_OBJC`

Objective-C language.

Symbol | Version
--- | ---
`__OBJC__` | detection

##### `BOOST_LANG_STDC`

Standard C language. If available, the year of the standard is detected as YYYY.MM.1 from the Epoc date.

Symbol | Version
--- | ---
`__STDC__` | detection
`__STDC_VERSION__` | V.R.P

##### `BOOST_LANG_STDCPP`

Standard C++ language. If available, the year of the standard is detected as YYYY.MM.1 from the Epoc date. Because of the way the C++ standardization process works the defined version year will not be the commonly known year of the standard. Specifically the defined versions are:

Table 1. Detected Version Number vs. C++ Standard Year

Detected Version Number | Standard Year | C++ Standard
--- | --- | ---
27.11.1 | 1998 | ISO/IEC 14882:1998
41.12.1 | 2011 | ISO/IEC 14882:2011

Symbol | Version
--- | ---
`__cplusplus` | detection
`__cplusplus` | YYYY.MM.1

##### `BOOST_LANG_STDCPPCLI`

Standard C++/CLI language. If available, the year of the standard is detected as YYYY.MM.1 from the Epoc date.

Symbol | Version
--- | ---
`__cplusplus_cli` | detection
`__cplusplus_cli` | YYYY.MM.1

##### `BOOST_LANG_STDECPP`

Standard Embedded C++ language.

Symbol | Version
--- | ---
`__embedded_cplusplus` | detection